@@ -137,6 +137,7 @@ class MeldWindow(gnomeglade.Component):
             ("Paste",   gtk.STOCK_PASTE,    None, None, _("Paste the clipboard"), self.on_menu_paste_activate),
             ("Find",    gtk.STOCK_FIND,     None, None, _("Search for text"), self.on_menu_find_activate),
             ("FindNext", None,              _("Find Ne_xt"), "<control>G", _("Search forwards for the same text"), self.on_menu_find_next_activate),
+            ("FindPrevious", None,          _("Find _Previous"), "<control><shift>G", _("Search backwards for the same text"), self.on_menu_find_previous_activate),
             ("Replace", gtk.STOCK_FIND_AND_REPLACE, _("_Replace"), "<control>H", _("Find and replace text"), self.on_menu_replace_activate),
             ("Preferences", gtk.STOCK_PREFERENCES, _("Prefere_nces"), None, _("Configure the application"), self.on_menu_preferences_activate),
 
@@ -420,6 +421,9 @@ class MeldWindow(gnomeglade.Component):
     def on_menu_find_next_activate(self, *extra):
         self.current_doc().on_find_next_activate()
 
+    def on_menu_find_previous_activate(self, *extra):
+        self.current_doc().on_find_previous_activate()
+
     def on_menu_replace_activate(self, *extra):
         self.current_doc().on_replace_activate()
 
@@ -646,10 +650,24 @@ class MeldWindow(gnomeglade.Component):
             self.scheduler.remove_scheduler(doc.scheduler)
         self.scheduler.add_task(cleanup)
         self.scheduler.add_scheduler(doc.scheduler)
+        path = os.path.abspath(path)
         doc.set_location(path)
         doc.connect("create-diff", lambda obj,arg: self.append_diff(arg))
         doc.run_diff([path])
 
+    def open_paths(self, paths, auto_compare=False):
+        tab = None
+        if len(paths) == 1:
+            a = paths[0]
+            if os.path.isfile(a):
+                self._single_file_open(a)
+            else:
+                tab = self.append_vcview(a, auto_compare)
+
+        elif len(paths) in (2, 3, 4):
+            tab = self.append_diff(paths, auto_compare)
+        return tab
+
     def current_doc(self):
         "Get the current doc or a dummy object if there is no current"
         index = self.notebook.get_current_page()
